[gnome-tweak-tool] Fix a typo
- From: John Stowers <jstowers src gnome org>
- To: commits-list gnome org
- Cc:
- Subject: [gnome-tweak-tool] Fix a typo
- Date: Fri, 6 May 2011 03:22:53 +0000 (UTC)
commit 2c980d769101108e361f0ec95b039080b03caaa1
Author: Jean-François Fortin Tam <nekohayo gmail com>
Date: Thu May 5 22:48:52 2011 -0400
Fix a typo
gtweak/tweaks/tweak_shell.py | 4 ++--
1 files changed, 2 insertions(+), 2 deletions(-)
---
diff --git a/gtweak/tweaks/tweak_shell.py b/gtweak/tweaks/tweak_shell.py
index 3a50385..9ff7ac4 100644
--- a/gtweak/tweaks/tweak_shell.py
+++ b/gtweak/tweaks/tweak_shell.py
@@ -109,10 +109,10 @@ class ShellThemeTweak(Tweak):
os.path.exists(os.path.join(d, "gnome-shell", "gnome-shell.css")))
#build a combo box with all the valid theme options
#manually add Adwiata to represent the default
cb = build_combo_box_text(
self._settings.get_string(ShellThemeTweak.THEME_GSETTINGS_NAME),
- ("", "Adwiata"),
+ ("", "Adwaita"),
*[(v,v) for v in valid])
cb.connect('changed', self._on_combo_changed)
hb.pack_start(cb, False, False, 5)
@@ -109,10 +109,10 @@ class ShellThemeTweak(Tweak):
os.path.exists(os.path.join(d, "gnome-shell", "gnome-shell.css")))
#build a combo box with all the valid theme options
- #manually add Adwiata to represent the default
+ #manually add Adwaita to represent the default
cb = build_combo_box_text(
self._settings.get_string(ShellThemeTweak.THEME_GSETTINGS_NAME),
[
Date Prev][
Date Next] [
Thread Prev][
Thread Next]
[
Thread Index]
[
Date Index]
[
Author Index]